@@ -763,13 +763,13 @@ gint confirm_newreminder(AppUIData *pui )
   if (db_get_numof_alarmtypes(currentcar) == 0) {
 #if PLAINGTK == 0
     confirmdlg = hildon_note_new_confirmation(GTK_WINDOW(pui->app->alarmwindow), 
-		 _("You haven't defined any reminders yet. You will have to have a reminder before adding any events. Choose OK to add a reminder, Cancel to close the dialog without adding a reminder."));
+		 _("You haven't defined any reminders yet. You will have to have a reminder before adding any events. Would you like to add a reminder now?"));
 #else
     confirmdlg = gtk_message_dialog_new(GTK_WINDOW(pui->app->alarmwindow),
 					GTK_DIALOG_MODAL,
 					GTK_MESSAGE_QUESTION,
 					GTK_BUTTONS_OK_CANCEL,
-					_("You haven't defined any reminders yet. You will have to have a reminder before adding any events. Choose OK to add a reminder, Cancel to close the dialog without adding a reminder."));
+					_("You haven't defined any reminders yet. You will have to have a reminder before adding any events. Would you like to add a reminder now?"));
     gtk_widget_show(confirmdlg);
 #endif
     confirm = gtk_dialog_run(GTK_DIALOG(confirmdlg));
